@@ -1,8 +1,5 @@
-import os
-import requests
 from pathlib import Path
 
-import kubify.src.kubify
 import kubify.src.core.app_constants as app_constants
 from pytest_kind import KindCluster
 
@@ -18,19 +15,9 @@ apiVersion: kind.x-k8s.io/v1alpha4
 nodes:
 - role: control-plane
   extraMounts:
-  - hostPath: "{app_constants.git_dir}/../"
-    containerPath: /src/kubify
-    readOnly: false
-  - hostPath: "{app_constants.home}/.aws"
-    containerPath: /root/.aws
-  - hostPath: "{app_constants.home}/.ssh"
-    containerPath: /root/.ssh
-  - hostPath: /var/run/docker.sock
-    containerPath: /var/run/docker.sock
-    propagation: HostToContainer
-    readOnly: false
-  - hostPath: "{app_constants.certs_path}"
-    containerPath: /usr/local/certificates
+  - hostPath: "{app_constants.root_dir_full_path}"
+    containerPath: /var/folders/kubify
+    readOnly: true
   kubeadmConfigPatches:
   - |
     kind: InitConfiguration
@@ -44,14 +31,14 @@ nodes:
   - containerPort: 443
     hostPort: 8443
     protocol: TCP
-        """
+"""
         kind_yaml = f"{app_constants.kubify_work}/kind.yaml"
         kind_yaml_path = Path(kind_yaml)
         kind_yaml_path.touch(exist_ok=True)
         with open(kind_yaml_path, "w+") as file:
             file.write(deployment_manifest_yaml)
         kind_cluster = KindCluster(name="kubify")
-        kind_cluster.create(config_file=kind_yaml_path)
+        kind_cluster.create(config_file=kind_yaml)
         kind_cluster.kubectl(
             "apply",
             "-f",
